@@ -2,13 +2,13 @@
     Kopete Groupwise Protocol
     keepalivetask.cpp - Send keepalive pings to the server
 
-    Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
+    Copyright (c) 2004      SUSE Linux AG	     http://www.suse.com
               (c) 2006      Novell, Inc.
 
     Based on Iris, Copyright (C) 2003  Justin Karneges <justin@affinix.com>
 
     Kopete (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
- 
+
     *************************************************************************
     *                                                                       *
     * This library is free software; you can redistribute it and/or         *
@@ -24,19 +24,16 @@
 #include "request.h"
 #include "requestfactory.h"
 
-KeepAliveTask::KeepAliveTask(Task* parent): RequestTask(parent)
+KeepAliveTask::KeepAliveTask(Task *parent) : RequestTask(parent)
 {
 }
 
-
 KeepAliveTask::~KeepAliveTask()
 {
 }
 
 void KeepAliveTask::setup()
 {
-	Field::FieldList lst;
-	createTransfer( "ping", lst );
+    Field::FieldList lst;
+    createTransfer(QStringLiteral("ping"), lst);
 }
-
-#include "keepalivetask.moc"
